#
# spec file for package python-mechanize
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-mechanize
Version:        0.2.5
Release:        20.2
Url:            http://wwwsearch.sourceforge.net/mechanize/
Summary:        Stateful programmatic web browsing
License:        (BSD-3-Clause or ZPL-2.1) and BSD-3-Clause
Group:          Development/Languages/Python
Source:         mechanize-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-devel
BuildRequires:  python-setuptools
Requires:       python-ClientForm
Requires:       python-beautifulsoup
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Stateful programmatic web browsing, after Andy Lester's Perl module
WWW::Mechanize.

The library is layered: mechanize.Browser (stateful web browser),
mechanize.UserAgent (configurable URL opener), plus urllib2 handlers.

Features include: ftp:, http: and file: URL schemes, browser history,
high-level hyperlink and HTML form support, HTTP cookies, HTTP-EQUIV and
Refresh, Referer [sic] header, robots.txt, redirections, proxies, and Basic and
Digest HTTP authentication. mechanize's response objects are (lazily-)
.seek()able and still work after .close().

Much of the code originally derived from Perl code by Gisle Aas (libwww-perl),
Johnny Lee (MSIE Cookie support) and last but not least Andy Lester
(WWW::Mechanize). urllib2 was written by Jeremy Hylton.

%prep
%setup -q -n mechanize-%{version}
sed -i "1d" examples/{forms/echo.cgi,forms/example.py,forms/simple.py} # Fix doc-file-dependency

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root)
%doc examples COPYING.txt README.txt docs/html/ChangeLog.txt
%{python_sitelib}/*

%changelog
* Sat Nov  9 2013 p.drouand@gmail.com
- Fix changes file by removing name of committer
- Fix Group : Development/Libraries/Python > Development/Languages/Python
* Sat Nov  9 2013 saigkill@opensuse.org
- changed BR python-clientform to python-ClientForm (now it matches)
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon Mar 12 2012 saschpe@gmx.de
- Simplified macro usage
* Wed Sep 21 2011 saschpe@suse.de
- Set license to "(BSD-3-Clause or ZPL-2.1) and BSD-3-Clause", bnc#719310
* Tue Sep 20 2011 saschpe@suse.de
- Update to version 0.2.5:
  * This is essentially a no-changes release to fix easy_install
    breakage caused by a SourceForge issue
  * Sourceforge is returning invalid HTTP responses, make download
    links point to PyPI instead
  * Include cookietest.cgi in source distribution
  * Note new IETF cookie standardisation effort
- Fixed doc-file-dependency rpmlint issue
* Fri Oct 29 2010 rwobben@hotmail.com
- update to version 0.2.4
  * Fix IndexError on empty Content-type header value. (GH-18)
  * Fall back to another encoding if an unknown one is declared.
    Fixes traceback on unknoqn encoding in Content-type header. (GH-30)
- additional changes from version 0.2.3
  * Fix str(ParseError()) traceback. (GH-25)
  * Add equality methods to mechanize.Cookie . (GH-29)
- additional changes from version 0.2.2
  * Officially support Python 2.7 (no changes were required)
  * Fix TypeError on .open()ing ftp: URL (only affects Python 2.4
    and 2.5)
  * Don't include HTTPSHandler in __all__ if it's not available
- additional changes from version 0.2.0
  * Behaviour change: merged upstream urllib2 change (allegedly a
    "bug fix") to return a response for all 2** HTTP responses (e.g.
    206 Partial Content).  Previously, only 200 caused a response
    object to be returned.  All other HTTP response codes resulted
    in a response object being raised as an exception.
  * Behaviour change: Use of mechanize classes with `urllib2` (and
    vice-versa) is no longer supported.  However, existing classes
    implementing the urllib2 Handler interface are likely to work
    unchanged with mechanize.  Removed RequestUpgradeProcessor,
    ResponseUpgradeProcessor, SeekableProcessor.
  * ClientForm has been merged into mechanize.  This means that
    mechanize has no dependencies other than Python itself.  The
    ClientForm API is still available -- to switch from ClientForm to
    mechanize, just s/ClientForm/mechanize in your source code, and
    ensure any use of the module logging logger named "ClientForm" is
    updated to use the new logger name "mechanize.forms".  I probably
    won't do further standalone releases of ClientForm.
  for the remaining changes in 0.2.0 and 0.2.1 see
  /usr/share/doc/packages/python-mechanize/ChangeLog.txt
* Thu Jul  1 2010 toms@suse.de
- Added check for openSUSE 11.1 and build arch
* Thu Jul  1 2010 toms@suse.de
- Merging from my home repo:
  - updated to 0.1.11
  - Set buildarch to noarch
  - Extended changelog
  - Added rpmlintrc file
* Thu Jul  2 2009 toms@suse.de
- Removed provides (wrong package)
* Tue Jun 30 2009 toms@suse.de
- Added provides for python-ClientForm
* Sat Jun 13 2009 toms@suse.de
- Fixed package typo: python-clientform -> python-ClientForm.
  Thanks to Alfredo J. V. P.!
* Sat Feb 21 2009 toms@suse.de
- Update to 0.1.11
* Tue Feb 12 2008 poeml@suse.de
- update to 0.1.7b
* Fri Jan 19 2007 judas_iscariote@shorewall.net
- update
* Wed Aug 30 2006 jfunk@funktronics.ca
- Initial release
